        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 27 <strong>control</strong><br>0,5,6,10,13,14,15,17,18,19,20,23,24,26,28,29,30,31,32,33,35,37,39,40,43,44,45';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 24 <br>1,2,3,4,7,8,9,11,12,16,21,22,25,27,34,36,38,41,42,46,47,48,49,50';}
}
